@@ -23,6 +23,17 @@ Medical Language System (UMLS)
 
 =head2 Optional Arguments:
 
+=head3 --infile FILE
+
+A file containing a list of concepts or terms. The format requires 
+a single concept and/or term per line. For example:
+  
+  cui1
+  term1
+  cui2
+  term2
+  ...
+
 =head3 --debug
 
 Sets the debug flag for testing
@@ -120,7 +131,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s")) or die ("Please check the above mentioned option(s).\n");
+eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "infile=s")) or die ("Please check the above mentioned option(s).\n");
 
 
 #  if help is defined, print out help
@@ -137,9 +148,11 @@ if( defined $opt_version ) {
     exit;
 }
 
-# At least 1 CUI should be given on the command line.
-if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line\n";
+# At least 1 term or cui  should be given on the command line.
+# unless the infile option was specified
+if( !(defined $opt_infile) and (scalar(@ARGV) < 1) ) {
+    print STDERR "At least 1 term or CUI should be given on the \n";
+    print STDERR "command line or use the --infile option\n";
     &minimalUsageNotes();
     exit;
 }
@@ -182,41 +195,55 @@ if(defined $opt_socket) {
 $umls = UMLS::Interface->new(\%option_hash); 
 die "Unable to create UMLS::Interface object.\n" if(!$umls);
 
-my $input = shift;
 
-my $term  = $input;
 
-my @c = ();
-if($input=~/C[0-9]/) {
-    push @c, $input;
-    ($term) = $umls->getTermList($input);
+my @terms = ();
+if(defined $opt_infile) { 
+    open(INFILE, $opt_infile) || die "Could not open infile ($opt_infile)\n";
+    while(<INFILE>) { 
+	chomp;
+	push @terms, $_;
+    } close INFILE;
 }
 else {
-    @c = $umls->getConceptList($input);
+    my $term = shift;
+    push @terms, $term;
 }
 
-my $printFlag = 0;
+foreach my $input (@terms) {
 
-foreach my $cui (@c) {
-    
-    my @sts = $umls->getSt($cui);
-    
-    if($#sts < 0) {
-	print "There are no semantic types associated with $term ($cui)\n";
+    my @c = ();
+    if($input=~/C[0-9]/) {
+	push @c, $input;
+	($term) = $umls->getTermList($input);
     }
     else {
-	print "The semantic types associated with $term ($cui):\n";
+	@c = $umls->getConceptList($input);
+    }
+    
+    my $printFlag = 0;
+    
+    foreach my $cui (@c) {
+	
+	my @sts = $umls->getSt($cui);
+	
+	if($#sts < 0) {
+	    print "There are no semantic types associated with $term ($cui)\n";
+	}
+	else {
+	    print "The semantic types associated with $term ($cui):\n";
 	foreach my $st (@sts) {
 	    my $abr = $umls->getStAbr($st);
 	    my $string = $umls->getStString($abr);
 	    print "  $string ($abr)\n";
 	}
+	}
+	$printFlag = 1;
     }
-    $printFlag = 1;
-}
 
-if(! ($printFlag) ) {
-    print "There are no semantic types associated with $input\n";
+    if(! ($printFlag) ) {
+	print "There are no semantic types associated with $input\n";
+    }
 }
 
 ##############################################################################
@@ -242,6 +269,9 @@ sub showHelp() {
 
     print "Options:\n\n";
     
+    print "--infile FILE            A file containing a list of concepts \n";
+    print "                         or terms.\n\n";
+
     print "--debug                  Sets the debug flag for testing\n\n";
 
     print "--username STRING        Username required to access mysql\n\n";
@@ -263,7 +293,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getSts.pl,v 1.10 2011/01/11 18:09:39 btmcinnes Exp $';
+    print '$Id: getSts.pl,v 1.11 2011/01/16 22:51:42 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
